==> otu-5000-17.04.tar: usr/share/pydiag/eotdrv2/eotdrv2_regs.py <==
REG_TEETH_NUMBER       = 0x00
REG_XOFFSET_DURATION   = 0x04
REG_MASQ_DURATION      = 0x08
REG_WAIT_DURATION      = 0x0C
REG_NOISE_DURATION     = 0x10
REG_AVERAGE_NUMBER     = 0x14
REG_RAMP_INCR          = 0x18
REG_RAMP_RESET_VAL     = 0x1C
REG_COMB_NUMBER        = 0x20
REG_COMB_INCR          = 0x24
REG_CRUNCH_NUMBER      = 0x28
REG_LPDDR_ADDR_OFFSET  = 0x2C
REG_LASER_WIDTH_ENT    = 0x30
REG_LASER_WIDTH_DEC    = 0x34
REG_LASER_ENABLE       = 0x38
REG_OFFSET_CONTINU     = 0x44
REG_MISC               = 0x48
REG_HARDWARE_CFG       = 0x4C
REG_TOTAL_TEETH_NB_CAL = 0x50
REG_FORCE_COMB         = 0x54
REG_FSM                = 0x58
REG_COUNT_SYNC         = 0x5c
REG_PRIME_RECUR        = 0x60
REG_DATA_LOG          = 0x64
REG_DAC_VCC_APD        = 0x68
REG_DAC_CONSIGNE_RAMAN = 0x6C
REG_DAC_CONSIGNE_LASER = 0x70
REG_DAC_CONSIGNE_TEC   = 0x74
REG_DAC_CONSIGNE_TEC_AUTO = 0x78
REG_DAC_CONSIGNE_LAS_DELTA = 0x7C
REG_PID_Kp             = 0x80
REG_PID_Ki             = 0x84
REG_PID_Kd             = 0x88
REG_PID_P_DEBUG        = 0x8C
REG_PID_I_DEBUG        = 0x90
REG_PID_D_DEBUG        = 0x94
REG_PID_OUTPUT_DEBUG   = 0x98
REG_PID_TEC_STATUS     = 0x9C
REG_AVG_CURRENT        = 0xA0
REG_DUTY_CYCLE         = 0xA4


REG_MISC_LASER_IN_PROGRESS = 0x00200000
REG_MISC_IRQ_BDT           = 0x00100000
REG_MISC_MEAS_IN_PROGRESS  = 0x00020000
REG_MISC_PLL_LOCKED       = 0x00010000
REG_MISC_LASER_ON         = 0x00000100
REG_MISC_EN_CUMUL         = 0x00000008
REG_MISC_BDT_ON           = 0x00000040
REG_MISC_START_MEAS       = 0x00000010
REG_MISC_CLEAR_IRQ        = 0x00000002
REG_MISC_ENABLE_IRQ       = 0x00000001

REG_HW_APD_GAIN           = 0x00000003
REG_HW_APD_MASQ_GAIN      = 0x00000030
REG_HW_CMD_LP             = 0x00000300
REG_HW_CMD_FILTRE         = 0x00000800

==> otu-5000-21.36.tar: usr/share/pydiag/eotdrv2/eotdrv2_regs.py <==
# coding: utf-8
# machine: eotdrv2
REG_TEETH_NUMBER       = 0x00
REG_XOFFSET_DURATION   = 0x04
REG_MASQ_DURATION      = 0x08
REG_WAIT_DURATION      = 0x0C
REG_NOISE_DURATION     = 0x10
REG_AVERAGE_NUMBER     = 0x14
REG_RAMP_INCR          = 0x18
REG_RAMP_RESET_VAL     = 0x1C
REG_COMB_NUMBER        = 0x20
REG_COMB_INCR          = 0x24
REG_CRUNCH_NUMBER      = 0x28
REG_LPDDR_ADDR_OFFSET  = 0x2C
REG_LASER_WIDTH_ENT    = 0x30
REG_LASER_WIDTH_DEC    = 0x34
REG_LASER_ENABLE       = 0x38
REG_OFFSET_CONTINU     = 0x44
REG_MISC               = 0x48
REG_HARDWARE_CFG       = 0x4C
REG_TOTAL_TEETH_NB_CAL = 0x50
REG_FORCE_COMB         = 0x54
REG_FSM                = 0x58
REG_COUNT_SYNC         = 0x5c
REG_PRIME_RECUR        = 0x60
REG_DATA_LOG          = 0x64
REG_DAC_VCC_APD        = 0x68
REG_DAC_CONSIGNE_RAMAN = 0x6C
REG_DAC_CONSIGNE_LASER = 0x70
REG_DAC_CONSIGNE_TEC   = 0x74
REG_DAC_CONSIGNE_TEC_AUTO = 0x78
REG_DAC_CONSIGNE_LAS_DELTA = 0x7C
REG_PID_Kp         = 0x80
REG_PID_Ki             = 0x84
REG_PID_Kd             = 0x88
REG_PID_P_DEBUG        = 0x8C
REG_PID_I_DEBUG        = 0x90
REG_PID_D_DEBUG        = 0x94
REG_PID_LOG   = 0x98
REG_PID_STATUS      = 0x9C
REG_MEASI_AVG_RAW = 0xA0
REG_MEASI_AVG_DUTY = 0xA4

REG_MISC_LASER_IN_PROGRESS = 0x00200000
REG_MISC_IRQ_BDT           = 0x00100000
REG_MISC_MEAS_IN_PROGRESS  = 0x00020000
REG_MISC_PLL_LOCKED       = 0x00010000
REG_MISC_LASER_ON         = 0x00000100
REG_MISC_EN_CUMUL         = 0x00000008
REG_MISC_BDT_ON           = 0x00000040
REG_MISC_START_MEAS       = 0x00000010
REG_MISC_CLEAR_IRQ        = 0x00000002
REG_MISC_ENABLE_IRQ       = 0x00000001

REG_HW_APD_GAIN           = 0x00000003
REG_HW_APD_MASQ_GAIN      = 0x00000030
REG_HW_CMD_LP             = 0x00000300
REG_HW_CMD_FILTRE         = 0x00000800

REG_LASER_SOURCE_ENABLE                     =0xA8
REG_LASER_SOURCE_FREQ_MODULATION   =0xAC
REG_LASER_FREQ_FAST_MODULATION        =0xB0
